==> haskell-basic-prelude-0.7.0-326-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-basic-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 basic-prelude
version:              0.7.0
visibility:           public
id:                   basic-prelude-0.7.0-BGThg5OdvuAFkppxTVWi9L
key:                  basic-prelude-0.7.0-BGThg5OdvuAFkppxTVWi9L
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Dan Burton
homepage:             https://github.com/snoyberg/basic-prelude#readme
synopsis:
    An enhanced core prelude; a common foundation for alternate preludes.

description:
    Please see the README on Github at <https://github.com/snoyberg/basic-prelude#readme>

category:             Control, Prelude
abi:                  5292608cf7d9977e15a58b2ed233339e
exposed:              True
exposed-modules:      BasicPrelude CorePrelude
hidden-modules:       Paths_basic_prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/basic-prelude-0.7.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/basic-prelude-0.7.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/basic-prelude-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-basic-prelude
hs-libraries:         HSbasic-prelude-0.7.0-BGThg5OdvuAFkppxTVWi9L
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 filepath-1.4.2.2
    hashable-1.4.4.0-44s1yyL7bsg7gxbZe8O55H text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-2ikAr0D5DLKB57N2l8lLdR
    vector-0.13.2.0-Hj69nwJTcAJ4Jep1PSRV8B

haddock-interfaces:
    /usr/share/doc/haskell-basic-prelude/html/basic-prelude.haddock

haddock-html:         /usr/share/doc/haskell-basic-prelude/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-basic-prelude-0.7.0-327-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-basic-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 basic-prelude
version:              0.7.0
visibility:           public
id:                   basic-prelude-0.7.0-B6BdYSGK4Mp1dbDXD42Pox
key:                  basic-prelude-0.7.0-B6BdYSGK4Mp1dbDXD42Pox
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Dan Burton
homepage:             https://github.com/snoyberg/basic-prelude#readme
synopsis:
    An enhanced core prelude; a common foundation for alternate preludes.

description:
    Please see the README on Github at <https://github.com/snoyberg/basic-prelude#readme>

category:             Control, Prelude
abi:                  ece9e82116b8578d3b730eb1787d7ea1
exposed:              True
exposed-modules:      BasicPrelude CorePrelude
hidden-modules:       Paths_basic_prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/basic-prelude-0.7.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/basic-prelude-0.7.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/basic-prelude-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-basic-prelude
hs-libraries:         HSbasic-prelude-0.7.0-B6BdYSGK4Mp1dbDXD42Pox
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 filepath-1.4.2.2
    hashable-1.4.4.0-HcIU0jNirb1KY01FJoO6uU text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-BooESfmG3DbHMU6mBvbzIL
    vector-0.13.2.0-InZif5xbqP17OkTvptfKiM

haddock-interfaces:
    /usr/share/doc/haskell-basic-prelude/html/basic-prelude.haddock

haddock-html:         /usr/share/doc/haskell-basic-prelude/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
